==> eth-tester-0.1.0b21.tar.gz: eth-tester-0.1.0b21/eth_tester/backends/base.py <==
class BaseChainBackend(object):
    #
    # Snapshot API
    #
    def take_snapshot(self):
        raise NotImplementedError("Must be implemented by subclasses")

    def revert_to_snapshot(self, snapshot):
        raise NotImplementedError("Must be implemented by subclasses")

    def reset_to_genesis(self):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Fork block numbers
    #
    def set_fork_block(self, fork_name, fork_block):
        raise NotImplementedError("Must be implemented by subclasses")

    def get_fork_block(self, fork_name):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Meta
    #
    def time_travel(self, to_timestamp):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Mining
    #
    def mine_blocks(self, num_blocks=1, coinbase=None):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Accounts
    #
    def get_accounts(self):
        raise NotImplementedError("Must be implemented by subclasses")

    def add_account(self, private_key):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Chain data
    #
    def get_block_by_number(self, block_number, full_transaction=True):
        raise NotImplementedError("Must be implemented by subclasses")

    def get_block_by_hash(self, block_hash, full_transaction=True):
        raise NotImplementedError("Must be implemented by subclasses")

    def get_transaction_by_hash(self, transaction_hash):
        raise NotImplementedError("Must be implemented by subclasses")

    def get_transaction_receipt(self, transaction_hash):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Account state
    #
    def get_nonce(self, account, block_number=None):
        raise NotImplementedError("Must be implemented by subclasses")

    def get_balance(self, account, block_number=None):
        raise NotImplementedError("Must be implemented by subclasses")

    def get_code(self, account, block_number=None):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Transactions
    #
    def send_transaction(self, transaction):
        raise NotImplementedError("Must be implemented by subclasses")

    def send_signed_transaction(self, transaction):
        raise NotImplementedError("Must be implemented by subclasses")

    def estimate_gas(self, transaction):
        raise NotImplementedError("Must be implemented by subclasses")

    def call(self, transaction, block_number="latest"):
        raise NotImplementedError("Must be implemented by subclasses")

==> eth-tester-0.6.0b3.tar.gz: eth-tester-0.6.0b3/eth_tester/backends/base.py <==
from abc import (
    ABCMeta,
    abstractmethod,
)


class BaseChainBackend(metaclass=ABCMeta):
    #
    # Snapshot API
    #
    @abstractmethod
    def take_snapshot(self):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def revert_to_snapshot(self, snapshot):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def reset_to_genesis(self):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Meta
    #
    @abstractmethod
    def time_travel(self, to_timestamp):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Mining
    #
    @abstractmethod
    def mine_blocks(self, num_blocks=1, coinbase=None):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Accounts
    #
    @abstractmethod
    def get_accounts(self):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def add_account(self, private_key):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Chain data
    #
    @abstractmethod
    def get_block_by_number(self, block_number, full_transaction=True):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def get_block_by_hash(self, block_hash, full_transaction=True):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def get_transaction_by_hash(self, transaction_hash):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def get_transaction_receipt(self, transaction_hash):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Account state
    #
    @abstractmethod
    def get_nonce(self, account, block_number=None):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def get_balance(self, account, block_number=None):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def get_code(self, account, block_number=None):
        raise NotImplementedError("Must be implemented by subclasses")

    #
    # Transactions
    #
    @abstractmethod
    def send_transaction(self, transaction):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def send_signed_transaction(self, transaction):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def estimate_gas(self, transaction, block_number="latest"):
        raise NotImplementedError("Must be implemented by subclasses")

    @abstractmethod
    def call(self, transaction, block_number="latest"):
        raise NotImplementedError("Must be implemented by subclasses")
